# DepthAI SDK

[![Discord](https://img.shields.io/discord/790680891252932659?label=Discord)](https://discord.gg/luxonis)
[![Forum](https://img.shields.io/badge/Forum-discuss-orange)](https://discuss.luxonis.com/)
[![Docs](https://img.shields.io/badge/Docs-DepthAI_SDK-yellow)](https://docs.luxonis.com/projects/sdk)
[![License: MIT](https://img.shields.io/badge/License-MIT-green.svg)](https://opensource.org/licenses/MIT)
[![](https://img.shields.io/pypi/v/depthai-sdk.svg)](https://pypi.org/project/depthai-sdk/)

DepthAI SDK is a Python package, containing convenience classes and functions that help in most common tasks while using DepthAI API.

To know more about the DepthAI itself, visit [our documentation](https://docs.luxonis.com/projects/sdk/en/latest/) or [our webpage](https://luxonis.com)

## Installation

To install this package, run the following command in your terminal window

```
$ python3 -m pip install depthai-sdk
```

> :warning: **If you're using Raspberry Pi**, providing a Pi Wheels extra package url can significantly speed up the installation process by providing prebuilt binaries for OpenCV
> ```
> $ pip install --extra-index-url https://www.piwheels.org/simple/ depthai-sdk
> ```

## Usage

Please visit [DepthAI SDK documentation page](https://docs.luxonis.com/projects/sdk/en/latest/).


## API

Please visit [DepthAI SDK API](https://docs.luxonis.com/projects/sdk/en/latest/api/) for full API reference
